/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../common/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dmr13MessageWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::MessageWindow::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr13MessageWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::MessageWindow"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MessageWindow, qt_meta_tag_ZN3dmr13MessageWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::MessageWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr13MessageWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr13MessageWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr13MessageWindowE_t>.metaTypes,
    nullptr
} };

void dmr::MessageWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MessageWindow *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dmr::MessageWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MessageWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr13MessageWindowE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::MessageWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dmr10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::MainWindow",
        "windowEntered",
        "",
        "windowLeaved",
        "initChanged",
        "frameMenuEnable",
        "playSpeedMenuEnable",
        "subtitleMenuEnable",
        "soundMenuEnable",
        "WMChanged",
        "isWM",
        "play",
        "listFiles",
        "slotFinishedAddFiles",
        "QList<QUrl>",
        "updateProxyGeometry",
        "suspendToolsWindow",
        "resumeToolsWindow",
        "checkOnlineState",
        "bIsOnline",
        "checkOnlineSubtitle",
        "OnlineSubtitle::FailReason",
        "reason",
        "checkErrorMpvLogsChanged",
        "sPrefix",
        "sText",
        "checkWarningMpvLogsChanged",
        "slotdefaultplaymodechanged",
        "sKey",
        "QVariant",
        "value",
        "onSetDecodeModel",
        "key",
        "onRefreshDecode",
        "my_setStayOnTop",
        "const QWidget*",
        "pWidget",
        "bOn",
        "slotmousePressTimerTimeOut",
        "slotPlayerStateChanged",
        "slotFocusWindowChanged",
        "slotFileLoaded",
        "slotUrlpause",
        "bStatus",
        "slotFontChanged",
        "QFont",
        "font",
        "slotMuteChanged",
        "bMute",
        "slotVolumeChanged",
        "nVolume",
        "slotWMChanged",
        "slotMediaError",
        "slotUpdateMircastState",
        "state",
        "msg",
        "slotExitMircast",
        "setInit",
        "bInit",
        "menuItemInvoked",
        "QAction*",
        "pAction",
        "onBindingsChanged",
        "updateActionsState",
        "animatePlayState",
        "resizeByConstraints",
        "bForceCentered",
        "onWindowStateChanged",
        "miniButtonClicked",
        "sId",
        "startBurstShooting",
        "onBurstScreenshot",
        "QImage",
        "imgFrame",
        "timestamp",
        "delayedMouseReleaseHandler",
        "diskRemoved",
        "sDiskName",
        "sleepStateChanged",
        "bSleep",
        "lockStateChanged",
        "bLock",
        "onSysLockState",
        "serviceName",
        "QVariantMap",
        "key2value",
        "slotProperChanged",
        "slotUnsupported",
        "slotInvalidFile",
        "strFileName",
        "inited"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowEntered'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowLeaved'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameMenuEnable'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'playSpeedMenuEnable'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'subtitleMenuEnable'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'soundMenuEnable'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'WMChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void(const QList<QString> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Slot 'slotFinishedAddFiles'
        QtMocHelpers::SlotData<void(QList<QUrl>)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'updateProxyGeometry'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspendToolsWindow'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resumeToolsWindow'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkOnlineState'
        QtMocHelpers::SlotData<void(const bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'checkOnlineSubtitle'
        QtMocHelpers::SlotData<void(const OnlineSubtitle::FailReason)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'checkErrorMpvLogsChanged'
        QtMocHelpers::SlotData<void(const QString, const QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'checkWarningMpvLogsChanged'
        QtMocHelpers::SlotData<void(const QString, const QString)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'slotdefaultplaymodechanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onSetDecodeModel'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onRefreshDecode'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'my_setStayOnTop'
        QtMocHelpers::SlotData<void(const QWidget *, bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'slotmousePressTimerTimeOut'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlayerStateChanged'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFocusWindowChanged'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileLoaded'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUrlpause'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'slotFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'slotMuteChanged'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Slot 'slotVolumeChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 50 },
        }}),
        // Slot 'slotWMChanged'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMediaError'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateMircastState'
        QtMocHelpers::SlotData<void(int, QString)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 54 }, { QMetaType::QString, 55 },
        }}),
        // Slot 'slotExitMircast'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setInit'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'menuItemInvoked'
        QtMocHelpers::SlotData<void(QAction *)>(59, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 60, 61 },
        }}),
        // Slot 'onBindingsChanged'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateActionsState'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'animatePlayState'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'resizeByConstraints'
        QtMocHelpers::SlotData<void(bool)>(65, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'resizeByConstraints'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onWindowStateChanged'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'miniButtonClicked'
        QtMocHelpers::SlotData<void(const QString &)>(68, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 69 },
        }}),
        // Slot 'startBurstShooting'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onBurstScreenshot'
        QtMocHelpers::SlotData<void(const QImage &, qint64)>(71, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 72, 73 }, { QMetaType::LongLong, 74 },
        }}),
        // Slot 'delayedMouseReleaseHandler'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'diskRemoved'
        QtMocHelpers::SlotData<void(QString)>(76, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 77 },
        }}),
        // Slot 'sleepStateChanged'
        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 79 },
        }}),
        // Slot 'lockStateChanged'
        QtMocHelpers::SlotData<void(bool)>(80, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 81 },
        }}),
        // Slot 'onSysLockState'
        QtMocHelpers::SlotData<void(QString, QVariantMap, QStringList)>(82, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 83 }, { 0x80000000 | 84, 85 }, { QMetaType::QStringList, 2 },
        }}),
        // Slot 'slotProperChanged'
        QtMocHelpers::SlotData<void(QString, QVariantMap, QStringList)>(86, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 84, 85 }, { QMetaType::QStringList, 2 },
        }}),
        // Slot 'slotUnsupported'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotInvalidFile'
        QtMocHelpers::SlotData<void(QString)>(88, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 89 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inited'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN3dmr10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<DMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr10MainWindowE_t>.metaTypes,
    nullptr
} };

void dmr::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowEntered(); break;
        case 1: _t->windowLeaved(); break;
        case 2: _t->initChanged(); break;
        case 3: _t->frameMenuEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->playSpeedMenuEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->subtitleMenuEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->soundMenuEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->WMChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->play((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 9: _t->slotFinishedAddFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 10: _t->updateProxyGeometry(); break;
        case 11: _t->suspendToolsWindow(); break;
        case 12: _t->resumeToolsWindow(); break;
        case 13: _t->checkOnlineState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->checkOnlineSubtitle((*reinterpret_cast<std::add_pointer_t<OnlineSubtitle::FailReason>>(_a[1]))); break;
        case 15: _t->checkErrorMpvLogsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->checkWarningMpvLogsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->slotdefaultplaymodechanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 18: _t->onSetDecodeModel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 19: _t->onRefreshDecode(); break;
        case 20: _t->my_setStayOnTop((*reinterpret_cast<std::add_pointer_t<const QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->slotmousePressTimerTimeOut(); break;
        case 22: _t->slotPlayerStateChanged(); break;
        case 23: _t->slotFocusWindowChanged(); break;
        case 24: _t->slotFileLoaded(); break;
        case 25: _t->slotUrlpause((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->slotFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 27: _t->slotMuteChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->slotVolumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->slotWMChanged(); break;
        case 30: _t->slotMediaError(); break;
        case 31: _t->slotUpdateMircastState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 32: _t->slotExitMircast(); break;
        case 33: _t->setInit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->menuItemInvoked((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 35: _t->onBindingsChanged(); break;
        case 36: _t->updateActionsState(); break;
        case 37: _t->animatePlayState(); break;
        case 38: _t->resizeByConstraints((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->resizeByConstraints(); break;
        case 40: _t->onWindowStateChanged(); break;
        case 41: _t->miniButtonClicked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->startBurstShooting(); break;
        case 43: _t->onBurstScreenshot((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 44: _t->delayedMouseReleaseHandler(); break;
        case 45: _t->diskRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->sleepStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->lockStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->onSysLockState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 49: _t->slotProperChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 50: _t->slotUnsupported(); break;
        case 51: _t->slotInvalidFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::windowEntered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::windowLeaved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::initChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::frameMenuEnable, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::playSpeedMenuEnable, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::subtitleMenuEnable, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::soundMenuEnable, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::WMChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->inited(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInit(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dmr::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return DMainWindow::qt_metacast(_clname);
}

int dmr::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dmr::MainWindow::windowEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::MainWindow::windowLeaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::MainWindow::initChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::MainWindow::frameMenuEnable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dmr::MainWindow::playSpeedMenuEnable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dmr::MainWindow::subtitleMenuEnable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dmr::MainWindow::soundMenuEnable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dmr::MainWindow::WMChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
