/****************************************************************************
** Meta object code from reading C++ file 'platform_toolbox_proxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../widgets/platform/platform_toolbox_proxy.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'platform_toolbox_proxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dmr18Platform_ImageItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::Platform_ImageItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr18Platform_ImageItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::Platform_ImageItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Platform_ImageItem, qt_meta_tag_ZN3dmr18Platform_ImageItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::Platform_ImageItem::staticMetaObject = { {
    QMetaObject::SuperData::link<DLabel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr18Platform_ImageItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr18Platform_ImageItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr18Platform_ImageItemE_t>.metaTypes,
    nullptr
} };

void dmr::Platform_ImageItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Platform_ImageItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dmr::Platform_ImageItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_ImageItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr18Platform_ImageItemE_t>.strings))
        return static_cast<void*>(this);
    return DLabel::qt_metacast(_clname);
}

int dmr::Platform_ImageItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DLabel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::Platform_IndicatorItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::Platform_IndicatorItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Platform_IndicatorItem, qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::Platform_IndicatorItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t>.metaTypes,
    nullptr
} };

void dmr::Platform_IndicatorItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Platform_IndicatorItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dmr::Platform_IndicatorItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_IndicatorItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr22Platform_IndicatorItemE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::Platform_IndicatorItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::Platform_ToolboxProxy::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::Platform_ToolboxProxy",
        "sigVolumeChanged",
        "",
        "int&",
        "nVolume",
        "sigMuteStateChanged",
        "bool&",
        "bMute",
        "sigUnsupported",
        "sigMircastState",
        "finishLoadSlot",
        "QSize",
        "size",
        "setthumbnailmode",
        "updateFullState",
        "slotUpdateMircast",
        "buttonClicked",
        "id",
        "buttonEnter",
        "buttonLeave",
        "updatePlayState",
        "updateMovieProgress",
        "updateButtonStates",
        "updateTimeVisible",
        "visible",
        "progressHoverChanged",
        "v",
        "updateHoverPreview",
        "QUrl",
        "url",
        "secs",
        "waitPlay",
        "slotThemeTypeChanged",
        "slotLeavePreview",
        "slotHidePreviewTime",
        "slotSliderPressed",
        "slotSliderReleased",
        "slotBaseMuteChanged",
        "sk",
        "QVariant",
        "val",
        "slotVolumeButtonClicked",
        "slotFileLoaded",
        "slotElapsedChanged",
        "slotApplicationStateChanged",
        "Qt::ApplicationState",
        "e",
        "slotPlayListStateChange",
        "isShortcut",
        "slotUpdateThumbnailTimeOut",
        "slotProAnimationFinished",
        "slotVolumeChanged",
        "slotMuteStateChanged",
        "updateMircastTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigVolumeChanged'
        QtMocHelpers::SignalData<void(int &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigMuteStateChanged'
        QtMocHelpers::SignalData<void(bool &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigUnsupported'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigMircastState'
        QtMocHelpers::SignalData<void(int, QString)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'finishLoadSlot'
        QtMocHelpers::SlotData<void(QSize)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setthumbnailmode'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateFullState'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateMircast'
        QtMocHelpers::SlotData<void(int, QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'buttonClicked'
        QtMocHelpers::SlotData<void(QString)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'buttonEnter'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'buttonLeave'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updatePlayState'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateMovieProgress'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateButtonStates'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateTimeVisible'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'progressHoverChanged'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'updateHoverPreview'
        QtMocHelpers::SlotData<void(const QUrl &, int)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'waitPlay'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotThemeTypeChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotLeavePreview'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotHidePreviewTime'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSliderPressed'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSliderReleased'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotBaseMuteChanged'
        QtMocHelpers::SlotData<void(QString, const QVariant &)>(37, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotVolumeButtonClicked'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFileLoaded'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotElapsedChanged'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotApplicationStateChanged'
        QtMocHelpers::SlotData<void(Qt::ApplicationState)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'slotPlayListStateChange'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Slot 'slotUpdateThumbnailTimeOut'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotProAnimationFinished'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotVolumeChanged'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'slotMuteStateChanged'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'updateMircastTime'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Platform_ToolboxProxy, qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::Platform_ToolboxProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<DFloatingWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t>.metaTypes,
    nullptr
} };

void dmr::Platform_ToolboxProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Platform_ToolboxProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigVolumeChanged((*reinterpret_cast<std::add_pointer_t<int&>>(_a[1]))); break;
        case 1: _t->sigMuteStateChanged((*reinterpret_cast<std::add_pointer_t<bool&>>(_a[1]))); break;
        case 2: _t->sigUnsupported(); break;
        case 3: _t->sigMircastState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->finishLoadSlot((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 5: _t->setthumbnailmode(); break;
        case 6: _t->updateFullState(); break;
        case 7: _t->slotUpdateMircast((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->buttonClicked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->buttonEnter(); break;
        case 10: _t->buttonLeave(); break;
        case 11: _t->updatePlayState(); break;
        case 12: _t->updateMovieProgress(); break;
        case 13: _t->updateButtonStates(); break;
        case 14: _t->updateTimeVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->progressHoverChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->updateHoverPreview((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: _t->waitPlay(); break;
        case 18: _t->slotThemeTypeChanged(); break;
        case 19: _t->slotLeavePreview(); break;
        case 20: _t->slotHidePreviewTime(); break;
        case 21: _t->slotSliderPressed(); break;
        case 22: _t->slotSliderReleased(); break;
        case 23: _t->slotBaseMuteChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 24: _t->slotVolumeButtonClicked(); break;
        case 25: _t->slotFileLoaded(); break;
        case 26: _t->slotElapsedChanged(); break;
        case 27: _t->slotApplicationStateChanged((*reinterpret_cast<std::add_pointer_t<Qt::ApplicationState>>(_a[1]))); break;
        case 28: _t->slotPlayListStateChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->slotUpdateThumbnailTimeOut(); break;
        case 30: _t->slotProAnimationFinished(); break;
        case 31: _t->slotVolumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotMuteStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->updateMircastTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Platform_ToolboxProxy::*)(int & )>(_a, &Platform_ToolboxProxy::sigVolumeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Platform_ToolboxProxy::*)(bool & )>(_a, &Platform_ToolboxProxy::sigMuteStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Platform_ToolboxProxy::*)()>(_a, &Platform_ToolboxProxy::sigUnsupported, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Platform_ToolboxProxy::*)(int , QString )>(_a, &Platform_ToolboxProxy::sigMircastState, 3))
            return;
    }
}

const QMetaObject *dmr::Platform_ToolboxProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_ToolboxProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr21Platform_ToolboxProxyE_t>.strings))
        return static_cast<void*>(this);
    return DFloatingWidget::qt_metacast(_clname);
}

int dmr::Platform_ToolboxProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFloatingWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void dmr::Platform_ToolboxProxy::sigVolumeChanged(int & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dmr::Platform_ToolboxProxy::sigMuteStateChanged(bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dmr::Platform_ToolboxProxy::sigUnsupported()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::Platform_ToolboxProxy::sigMircastState(int _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::Platform_viewProgBarLoad::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::Platform_viewProgBarLoad",
        "leaveViewProgBar",
        "",
        "hoverChanged",
        "sliderMoved",
        "sigFinishiLoad",
        "QSize",
        "size",
        "loadViewProgBar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'leaveViewProgBar'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoverChanged'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'sliderMoved'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'sigFinishiLoad'
        QtMocHelpers::SignalData<void(QSize)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'loadViewProgBar'
        QtMocHelpers::SlotData<void(QSize)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Platform_viewProgBarLoad, qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::Platform_viewProgBarLoad::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t>.metaTypes,
    nullptr
} };

void dmr::Platform_viewProgBarLoad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Platform_viewProgBarLoad *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->leaveViewProgBar(); break;
        case 1: _t->hoverChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->sliderMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->sigFinishiLoad((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 4: _t->loadViewProgBar((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Platform_viewProgBarLoad::*)()>(_a, &Platform_viewProgBarLoad::leaveViewProgBar, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Platform_viewProgBarLoad::*)(int )>(_a, &Platform_viewProgBarLoad::hoverChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Platform_viewProgBarLoad::*)(int )>(_a, &Platform_viewProgBarLoad::sliderMoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Platform_viewProgBarLoad::*)(QSize )>(_a, &Platform_viewProgBarLoad::sigFinishiLoad, 3))
            return;
    }
}

const QMetaObject *dmr::Platform_viewProgBarLoad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_viewProgBarLoad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr24Platform_viewProgBarLoadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dmr::Platform_viewProgBarLoad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dmr::Platform_viewProgBarLoad::leaveViewProgBar()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::Platform_viewProgBarLoad::hoverChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dmr::Platform_viewProgBarLoad::sliderMoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dmr::Platform_viewProgBarLoad::sigFinishiLoad(QSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
